@@ -1,8 +1,21 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2002 Tobias Koenig <tokoe@kde.org>
+    Copyright (c) 2002 Tobias Koenig <tokoe@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef KCONTACTS_PICTURE_H
@@ -11,12 +24,12 @@
 #include "kcontacts_export.h"
 
 #include <QDataStream>
-#include <QImage>
-#include <QSharedDataPointer>
 #include <QString>
+#include <QSharedDataPointer>
 
-namespace KContacts
-{
+class QImage;
+
+namespace KContacts {
 class PicturePrivate;
 
 /**
@@ -28,12 +41,6 @@ class KCONTACTS_EXPORT Picture
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Picture &);
     friend KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, Picture &);
 
-    Q_GADGET
-    Q_PROPERTY(QImage data READ data WRITE setData)
-    Q_PROPERTY(QString url READ url WRITE setUrl)
-    Q_PROPERTY(bool isIntern READ isIntern)
-    Q_PROPERTY(bool isEmpty READ isEmpty)
-
 public:
     /**
      * Creates an empty picture.
@@ -68,7 +75,7 @@ public:
      */
     ~Picture();
 
-    typedef QList<Picture> List;
+    typedef QVector<Picture> List;
     /**
      * Assignment operator
      *
@@ -81,17 +88,17 @@ public:
     /**
      * Equality operator.
      */
-    Q_REQUIRED_RESULT bool operator==(const Picture &other) const;
+    bool operator==(const Picture &other) const;
 
     /**
      * Not-Equal operator.
      */
-    Q_REQUIRED_RESULT bool operator!=(const Picture &other) const;
+    bool operator!=(const Picture &other) const;
 
     /**
      * Returns true, if the picture is empty.
      */
-    Q_REQUIRED_RESULT bool isEmpty() const;
+    bool isEmpty() const;
 
     /**
      * Sets a URL for the location of the picture file. When using this
@@ -134,6 +141,13 @@ public:
      */
     void setRawData(const QByteArray &rawData, const QString &type);
 
+    /**
+     * Sets the type of the picture.
+     * @param type the picture's data type
+     * @deprecated type should only be set along with setRawData()
+     */
+    void KCONTACTS_DEPRECATED setType(const QString &type);
+
     /**
      * Returns whether the picture is described by a URL (extern) or
      * by the raw data (intern).
@@ -141,34 +155,34 @@ public:
      * get the raw data. Otherwise you can request the URL of this
      * picture by url() and load the raw data from that location.
      */
-    Q_REQUIRED_RESULT bool isIntern() const;
+    bool isIntern() const;
 
     /**
      * Returns the location URL of this picture.
      */
-    Q_REQUIRED_RESULT QString url() const;
+    QString url() const;
 
     /**
      * Returns the image data of this picture.
      */
-    Q_REQUIRED_RESULT QImage data() const;
+    QImage data() const;
 
     /**
      * Returns the raw data of this picture.
      *
      * @since 4.10
      */
-    Q_REQUIRED_RESULT QByteArray rawData() const;
+    QByteArray rawData() const;
 
     /**
      * Returns the type of this picture.
      */
-    Q_REQUIRED_RESULT QString type() const;
+    QString type() const;
 
     /**
      * Returns string representation of the picture.
      */
-    Q_REQUIRED_RESULT QString toString() const;
+    QString toString() const;
 
 private:
     QSharedDataPointer<PicturePrivate> d;
@@ -184,5 +198,5 @@ KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const Picture &pic
  */
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, Picture &picture);
 }
-Q_DECLARE_TYPEINFO(KContacts::Picture, Q_RELOCATABLE_TYPE);
+Q_DECLARE_TYPEINFO(KContacts::Picture, Q_MOVABLE_TYPE);
 #endif
