@@ -24,9 +24,7 @@
 #include "vcard.h"
 #include <QByteArray>
 
-namespace KContacts
-{
-
+namespace KContacts {
 class VCardParser
 {
 public:
@@ -41,7 +39,6 @@ private:
     class VCardParserPrivate;
     VCardParserPrivate *d;
 };
-
 }
 
 #endif
