@@ -27,9 +27,7 @@
 
 class QDateTime;
 
-namespace KContacts
-{
-
+namespace KContacts {
 class Key;
 class Picture;
 class Secrecy;
@@ -45,28 +43,25 @@ public:
       Creates a string that contains the addressees from the list in
       the vCard format.
      */
-    QByteArray createVCards(const Addressee::List &list,
-                            VCard::Version version = VCard::v3_0) const;
+    QByteArray createVCards(const Addressee::List &list, VCard::Version version = VCard::v3_0) const;
 
     /**
      * @since 4.9.1
      */
-    QByteArray exportVCards(const Addressee::List &list,
-                            VCard::Version version = VCard::v3_0) const;
+    QByteArray exportVCards(const Addressee::List &list, VCard::Version version = VCard::v3_0) const;
     /**
       Parses the string and returns a list of addressee objects.
      */
     Addressee::List parseVCards(const QByteArray &vcard) const;
 
-    static QDateTime parseDateTime(const QString &str, bool *timeValid = 0);
+    static QDateTime parseDateTime(const QString &str, bool *timeValid = nullptr);
     static QString createDateTime(const QDateTime &dateTime, VCard::Version version, bool withTime = true);
     static QString createDate(const QDate &date, VCard::Version version);
     static QString createTime(const QTime &time, VCard::Version version);
 
 private:
 
-    QByteArray createVCards(const Addressee::List &list,
-                            VCard::Version version, bool exportVcard) const;
+    QByteArray createVCards(const Addressee::List &list, VCard::Version version, bool exportVcard) const;
 
     /**
       Split a string and replaces escaped separators on the fly with
@@ -89,15 +84,10 @@ private:
     void addParameter(VCardLine &line, VCard::Version version, const QString &key, const QStringList &valueStringList) const;
     void addParameters(VCardLine &line, const QMap<QString, QStringList> &params) const;
 
-    QMap<QString, Address::TypeFlag> mAddressTypeMap;
-    QMap<QString, PhoneNumber::TypeFlag> mPhoneTypeMap;
     void imppService(const QString &serviceType, KContacts::Impp &impp) const;
 
     Q_DISABLE_COPY(VCardTool)
-    class VCardToolPrivate;
-    VCardToolPrivate *d;
 };
-
 }
 
 #endif
